#
# spec file for package libp11
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# the libname depends on what version openssl it is linked against
%if 0%{?suse_version} < 1500
# libp11.so.2 for openssl 1.0 - suse_version < 1500
%define libname libp11-2
%else
# libp11.so.3 for openssl 1.1 - suse_version >= 1500
%define libname libp11-3
%endif
Name:           libp11
Version:        0.4.13
Release:        1.1
Summary:        Library Implementing a Small Layer on Top of PKCS#11 API
License:        LGPL-2.1-or-later
Group:          Productivity/Security
URL:            https://github.com/OpenSC/libp11
Source0:        https://github.com/OpenSC/libp11/releases/download/%{name}-%{version}/%{name}-%{version}.tar.gz
Source1:        https://github.com/OpenSC/libp11/releases/download/%{name}-%{version}/%{name}-%{version}.tar.gz.asc
Source2:        %{name}.keyring
Source3:        %{name}-rpmlintrc
Source4:        baselibs.conf
# FIX-UPSTREAM
Patch0:         fix-wrong-non-static-lib.patch
BuildRequires:  fdupes
BuildRequires:  libtool
BuildRequires:  p11-kit-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(zlib)
# Required for testing
BuildRequires:  opensc
# For pgrep
BuildRequires:  procps
BuildRequires:  softhsm
# The engine_pkcs11 library has been merged into version 0.4.0 and later.
# (It existed only in security:chipcard OBS repository.
Obsoletes:      engine_pkcs11 <= 0.2.2

%description
Libp11 is a library implementing a small layer on top of PKCS#11 API to
make using PKCS#11 implementations easier.

The official name for PKCS#11 is "RSA Security Inc. PKCS #11
Cryptographic Token Interface (Cryptoki)".

Libp11 source code includes the official header files (version 2.20)
and thus is "derived from the RSA Security Inc. PKCS #11 Cryptographic
Token Interface (Cryptoki)".

%package -n %{libname}
Summary:        Library Implementing a Small Layer on Top of PKCS#11 API
Group:          Productivity/Security

%description -n %{libname}
Libp11 is a library implementing a small layer on top of PKCS#11 API to
make using PKCS#11 implementations easier.

The official name for PKCS#11 is "RSA Security Inc. PKCS #11
Cryptographic Token Interface (Cryptoki)".

Libp11 source code includes the official header files (version 2.20)
and thus is "derived from the RSA Security Inc. PKCS #11 Cryptographic
Token Interface (Cryptoki)".

%package -n openssl-engine-%{name}
Summary:        Library Implementing a Small Layer on Top of PKCS#11 API
Group:          Productivity/Security
# IBM dropped support for the openssl-ibmpkcs11 and will contribute to
# libp11 project instead. (jsc#PED-3327)
Provides:       openssl-ibmpkcs11 = 1.0.1
Obsoletes:      openssl-ibmpkcs11 <= 1.0.1

%description -n openssl-engine-%{name}
Libp11 is a library implementing a small layer on top of PKCS#11 API to
make using PKCS#11 implementations easier.

The official name for PKCS#11 is "RSA Security Inc. PKCS #11
Cryptographic Token Interface (Cryptoki)".

Libp11 source code includes the official header files (version 2.20)
and thus is "derived from the RSA Security Inc. PKCS #11 Cryptographic
Token Interface (Cryptoki)".

%package devel
Summary:        Library Implementing a Small Layer on Top of PKCS#11 API
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Requires:       openssl-devel

%description devel
Libp11 is a library implementing a small layer on top of PKCS#11 API to
make using PKCS#11 implementations easier.

The official name for PKCS#11 is "RSA Security Inc. PKCS #11
Cryptographic Token Interface (Cryptoki)".

Libp11 source code include the official header files (version 2.20) and
thus is "derived from the RSA Security Inc. PKCS #11 Cryptographic
Token Interface (Cryptoki)".

%prep
%autosetup -p1
# Since the library name changes based on used openssl, we have to create baselibs.conf dynamically
echo %{libname} > %{_sourcedir}/baselibs.conf

%build
autoreconf -fiv
%configure \
    --disable-static \
    --disable-silent-rules \
    --docdir=%{_docdir}/%{libname}
%make_build

%install
%make_install
mkdir -p %{buildroot}%{_docdir}/%{name} %{buildroot}%{_docdir}/%{libname}
find %{buildroot} -type f -name "*.la" -delete -print
%fdupes %{buildroot}%{_docdir}

%check
%make_build check

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%doc %{_docdir}/%{libname}
%{_libdir}/libp11.so.*

%files -n openssl-engine-%{name}
%if 0%{?suse_version} > 1325
%{_libdir}/engines-*
%else
%{_libdir}/engines
%endif

%files devel
%{_includedir}/*.h
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%changelog
* Fri Dec 20 2024 Lucas Mulling <lucas.mulling@suse.com>
- Add patch to fix upstream
  * fix-wrong-non-static-lib.patch
* Thu Dec 19 2024 Lucas Mulling <lucas.mulling@suse.com>
- Update to 0.4.13:
  * Increased maximum PIN length (Michał Trojnara)
  * Fixed several memory leaks (Michał Trojnara, Małgorzata Olszówka)
  * Don't include libp11.rc VERSIONINFO into pkcs11 (Mikhail Titov)
  * Improved tests (Małgorzata Olszówka)
  * Added static ENGINE (libpkcas11.a) build (Marouene Boubakri)
  * Added a workaround broken foreign key handling in OpenSSL
  * 3.0.12-3.0.13, 3.1.4-3.1.5, 3.2.0-3.2.1 (Małgorzata Olszówka)
  * Added a workaround for conflicting atexit() callbacks (Michał Trojnara)
  * Always login with PIN If FORCE_LOGIN is specified in openssl config
    (Plamen Todorov)
  * Added OAEP support to RSA_private_decrypt (Peter Popovec)
  * Added PKCS11_enumerate_*_ext functions (Harshal Gohel)
  * Fixed non-null-terminated label padding (Jorge Ramirez-Ortiz)
  * Fixed several object management issues (Jakub Jelen)
  * Deferred libp11 initialization until needed (Doug Engert)
- Removed patches:
  * libp11-openssl-3.1.patch
  * libp11-configure-treat-all-openssl-3.x-releases-the-same.patch
- Enable unit tests
* Fri Jan 19 2024 Otto Hollmann <otto.hollmann@suse.com>
- Add support for OpenSSL 3.x:
  Add libp11-configure-treat-all-openssl-3.x-releases-the-same.patch
* Wed Sep 27 2023 Otto Hollmann <otto.hollmann@suse.com>
- Replace openssl-ibmpkcs11 with openssl-engine-libp11 (jsc#PED-3327)
  Add Obsoletes: openssl-ibmpkcs11 <= 1.0.1
  and Provides: openssl-ibmpkcs11 = 1.0.1
* Tue Jun  6 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Add support for openSSL 3.1:
  + Add libp11-openssl-3.1.patch: handle openSSL 3.1 the same as 3.0
  + Add libtool BuildRequires and call autoreconf: abobe patch
    touches the build system.
  + Add baselibs.conf
* Mon Feb  6 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build against openSSL 3.
* Mon Oct 17 2022 Jason Sikes <jsikes@suse.com>
- Update to 0.4.12:
  * Fixed using an explicitly provided PIN regardless of the secure login flag (Alon Bar-Lev)
  * Fixed RSA_PKCS1_PADDING handling (Michał Trojnara)
  * Fixed a crash on LLP64, including 64-bit Windows (Małgorzata Olszówka)
  * Fixed searching objects when both ID and label are specified (minfrin)
  * Fixed the OAEP "source" parameter (S-P Chan)
  * Fixed object searching by label (Michał Trojnara)
  * Fixed thread safety in slot enumeration (Michał Trojnara)
  * Fixed storing certificates on tokens (Mateusz Kwiatkowski)
  * Fixed several memory leaks (Michał Trojnara, Jakub Jelen, Timo Teräs)
  * Fixed OpenSSL 3.0 compatibility (Jakub Jelen)
  * Fixed LibreSSL compatibility (orbea, patchMonkey156)
  * Major concurrency improvements and refactoring (Timo Teräs)
  * Added re-numeration of slots as an engine control command (Markus Koetter)
  * Added the PKCS11_update_slots() API function (Timo Teräs)
  * Added support for the SHA3 hash function (alegon01)
  * Added a self-test for engine RSA operations (Uri Blumenthal)
* Thu Nov 26 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.4.11:
  * Fixed "EVP_PKEY_derive:buffer too small" EC errors (Luka Logar)
  * Fixed various memory leaks (Mateusz Kwiatkowski)
  * Fixed Windows VERSIONINFO (Pavol Misik)
  * Fixed builds with OpenSSL older than 1.0.2 (Michał Trojnara)
  * Fixed a double free in EVP_PKEY_meth_free() (Mikhail Durnev)
  * Added CKA_VALUE_LEN to EC key derivation template (Michał Trojnara)
  * Fixed handling keys without label attribute (efternavn)
  * Updated the tests (Anderson Toshiyuki Sasaki)
  * Made ECDH-derived keys extractable (Bent Bisballe Nyeng)
  * Added support for pin-source within PKCS#11 URI (Stanislav Levin)
  * Improved LibreSSL compatibility (patchMonkey156)
  * Fixed handling RSA private keys in BIND (Stanislav Levin)
  * Added macOS testing support (Stanislav Levin)
  * Fixed engine object search algorithm (Anderson Toshiyuki Sasaki)
* Tue Oct 22 2019 Jason Sikes <jsikes@suse.com>
- Update to version 0.4.10:
  * Added EC signing through EVP API
  * Added an empty EC private key required by OpenSSL 1.1.1
  * Stored additional certificate attributes
  * Engine allowed to use private keys without a PIN
  * Lazy binding used as a workaround for buggy modules
  * MinGW build fixes and documentation
  * LibreSSL 2.8.3 build fixes
  * Error handling fixes
* Tue Mar 12 2019 Marketa Calabkova <mcalabkova@suse.com>
- Add p11-kit-devel to BuildRequires (boo#1122413)
* Tue Jan 29 2019 Stanislav Brabec <sbrabec@suse.com>
- Update to version 0.4.9:
  * Fix EVP_PKEY ENGINE reference count with the EC
    EVP_PKEY_METHOD.
  * Fix a leak of RSA object in pkcs11_store_key()
  * Add atfork checks for RSA and EC_KEY method
  * RSA key generation on the token
  * PSS signature support
  * RSA-OAEP and RSA-PKCS encryption support
  * Engine no longer set as default for all methods
  * Add PKCS11_remove_key and PKCS11_remove_certificate
  * Add PKCS11_find_next_token interface
  * Add support for OpenSSL 1.1.1 beta
  * Remove support for OpenSSL 0.9.8
  * Case insensitive PKCS#11 URI scheme
  * Testing framework improvements
  * Coverity scanning and defect fixes
  * Backward compatibility for new error handling introduced
    in libp11 0.4.7
  * Memory leak fixes
  * Add an integer overflow protection
  * Several bugfixes
* Wed Jan 17 2018 dimstar@opensuse.org
- Conditionalize libname to libp11-2 for suse_version < 1500 (using
  openssl 1.0) / libp11-3 for suse_version >= 1500 (using
  openssl 1.1).
- Create baselibs.conf dynamically, since the library name can be
  different. Drop the static baselibs.conf.
* Wed Jul 19 2017 jengelh@inai.de
- Remove --with-pic which is only for static libs.
* Mon Jul 17 2017 tchvatal@suse.com
- Version update to 0.4.7:
  * Added OpenSSL-style engine error reporting (Michał Trojnara)
  * Added the FORCE_LOGIN engine ctrl command (Michał Trojnara)
  * Implemented the QUIET engine ctrl command (Michał Trojnara)
  * Modified CKU_CONTEXT_SPECIFIC PIN requests to be based
    on the CKA_ALWAYS_AUTHENTICATE attribute rather than the
    CKR_USER_NOT_LOGGED_IN error (Michał Trojnara)
  * Fixed printing hex values (Michał Trojnara)
  * Fixed build error with OPENSSL_NO_EC (Kai Kang)
* Fri Jun 23 2017 mpluskal@suse.com
- Update to verion 0.4.6
  * For full list of changes since version 0.3.0 see NEWS
- Create openssl-engine-libp11 subpackage
- Add gpg signature
* Wed Dec  2 2015 p.drouand@gmail.com
- Update to version 0.3.0
  * Added small test suite based on softhsm (run on make check)
  * Memory leak fixes
  * On module initialization tell the module that the OS locking
    primitives are OK to use
  * Transparently handle applications that fork. That is call C_Initialize()
    and reopen any handles if a fork is detected.
  * Eliminated any hard coded limits for certificate size
  * Added support for ECDSA
  * Allow RSA_NO_PADDING padding mode in PKCS11_private_encrypt
  * Eliminated several hard-coded limits in parameter sizes.
- Update project and download Urls
* Tue Sep 25 2012 sbrabec@suse.cz
- Update to version 0.2.8:
  * Bumped soname for PKCS11_token struct size changes.
  * Display the number of available slots.
  * Expose more token flags in PKCS11_token structure.
  * Check that private data is not NULL in pkcs11_release_slot.
* Sun Nov 20 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Tue Jan 11 2011 sbrabec@suse.cz
-  Updated to version 0.2.7:
  * Ignore CKR_CRYPTOKI_ALREADY_INITIALIZED while initializing.
* Mon Feb  1 2010 jengelh@medozas.de
- Package baselibs.conf
* Wed Aug  5 2009 sbrabec@suse.cz
- Updated to version 0.2.6:
  * Add new symbol to export file.
  * Add function to export the slot id.
  * Increase library version because of the new function.
* Wed Apr  8 2009 sbrabec@suse.cz
- Don't call autoreconf on older products.
* Tue Sep  2 2008 sbrabec@suse.cz
- Call autoreconf to build correctly with new libtool.
* Tue Sep  2 2008 crrodriguez@suse.de
- fix build, doxygen required.
- kill ".la" files and static libraries
- fix -devel package requires
* Tue Aug 19 2008 sbrabec@suse.cz
- Updated to version 0.2.4:
  * Build system rewritten
  * added PKCS11_CTX_init_args
  * fix segfault in init_args code
  * implemented PKCS11_private_encrypt
- Fixed incorrect API.
- Fixed x86_64 issues.
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Sun Jul 29 2007 ro@suse.de
- provide old name
* Wed Jul 25 2007 sbrabec@suse.cz
- Updated to version 0.2.3:
  * update wiki export script.
  * replaced rsa header files from rsalabs (official) with scute
    (open source).
  * allow CKR_USER_ALREADY_LOGGED_IN on C_Login.
  * mark internal functions as static.
  * add code to store public keys and generate keys.
- Name package according to shared library packaging policy.
* Thu Mar 29 2007 ro@suse.de
- added zlib-devel to buildreq
* Tue Oct  3 2006 sbrabec@suse.cz
- Updated to version 0.2.2:
  * bug fixes
  * code cleanup
* Fri May 12 2006 sbrabec@suse.cz
- New SuSE package, version 0.2.1.
